pub struct ManagedScopeBinding { /* private fields */ }Expand description
Durable identity binding attached explicitly to one managed fact selection.
Implementations
Sourceimpl ManagedScopeBinding
impl ManagedScopeBinding
Sourcepub fn exclusive(id: ManagedScopeId) -> Result<Self, Diagnostic>
pub fn exclusive(id: ManagedScopeId) -> Result<Self, Diagnostic>
Bind a durable scope identity to the frozen exclusive profile.
Sourcepub const fn id(&self) -> &ManagedScopeId
pub const fn id(&self) -> &ManagedScopeId
Return the durable scope identity.
Sourcepub const fn profile(&self) -> &ManagedScopeProfileBinding
pub const fn profile(&self) -> &ManagedScopeProfileBinding
Return the frozen scope-profile binding.