pub struct BackfillStepContract { /* private fields */ }Expand description
Context-free claims derived exactly from one closed backfill plan.
Implementations
Sourceimpl BackfillStepContract
impl BackfillStepContract
Sourcepub const fn id(&self) -> &MigrationStepId
pub const fn id(&self) -> &MigrationStepId
Return the step-local identity.
Sourcepub const fn plan_fingerprint(&self) -> &Fingerprint
pub const fn plan_fingerprint(&self) -> &Fingerprint
Return the exact canonical backfill-plan fingerprint.
Sourcepub const fn required_capabilities(&self) -> &CapabilitySet
pub const fn required_capabilities(&self) -> &CapabilitySet
Return capabilities derived from the closed plan.
Sourcepub const fn reverse(&self) -> Option<BackfillReverseProgram>
pub const fn reverse(&self) -> Option<BackfillReverseProgram>
Return the optional independently verifiable reverse program.
Sourcepub const fn source_semantics(&self) -> &ManagedSemanticSchemaFingerprint
pub const fn source_semantics(&self) -> &ManagedSemanticSchemaFingerprint
Return the exact historical intermediate-schema precondition.
Sourcepub const fn target_semantics(&self) -> &ManagedSemanticSchemaFingerprint
pub const fn target_semantics(&self) -> &ManagedSemanticSchemaFingerprint
Return the schema semantics preserved by the data step.