pub struct SchemaDeltaStepContract { /* private fields */ }Expand description
Context-free claims derived exactly from a trusted schema delta.
Implementations
Sourceimpl SchemaDeltaStepContract
impl SchemaDeltaStepContract
Sourcepub fn new(
id: MigrationStepId,
delta: &SchemaDelta,
reverse: Option<SchemaDelta>,
) -> Result<Self, Diagnostic>
pub fn new( id: MigrationStepId, delta: &SchemaDelta, reverse: Option<SchemaDelta>, ) -> Result<Self, Diagnostic>
Derive all step claims and validate an optional exact operation-wise inverse.
Sourcepub const fn id(&self) -> &MigrationStepId
pub const fn id(&self) -> &MigrationStepId
Return the step-local identity.
Sourcepub const fn source_semantics(&self) -> &ManagedSemanticSchemaFingerprint
pub const fn source_semantics(&self) -> &ManagedSemanticSchemaFingerprint
Return the exact source managed-semantic precondition.
Sourcepub const fn target_semantics(&self) -> &ManagedSemanticSchemaFingerprint
pub const fn target_semantics(&self) -> &ManagedSemanticSchemaFingerprint
Return the exact target managed-semantic postcondition.
Sourcepub const fn required_capabilities(&self) -> &CapabilitySet
pub const fn required_capabilities(&self) -> &CapabilitySet
Return capabilities derived from the trusted delta.
Sourcepub const fn delta_fingerprint(&self) -> &SchemaDeltaFingerprint
pub const fn delta_fingerprint(&self) -> &SchemaDeltaFingerprint
Return the exact schema-delta fingerprint.
Sourcepub const fn retry(&self) -> RetryPolicy
pub const fn retry(&self) -> RetryPolicy
Return the fixed no-replay retry policy.
Sourcepub const fn recovery(&self) -> RecoveryPolicy
pub const fn recovery(&self) -> RecoveryPolicy
Return the fixed operator-required recovery policy.
Sourcepub const fn reverse(&self) -> Option<&SchemaDelta>
pub const fn reverse(&self) -> Option<&SchemaDelta>
Return the optional checked exact inverse.