pub struct BackfillPartition { /* private fields */ }Expand description
A deterministic partition contract bound to a stable historical attribute.
Implementations
Sourceimpl BackfillPartition
impl BackfillPartition
Sourcepub fn new(
batch_rows: u32,
stable_attribute: AttributeId,
) -> Result<Self, Diagnostic>
pub fn new( batch_rows: u32, stable_attribute: AttributeId, ) -> Result<Self, Diagnostic>
Construct a bounded deterministic partition contract.
Sourcepub const fn batch_rows(&self) -> u32
pub const fn batch_rows(&self) -> u32
Return the maximum rows in one transaction group.
Sourcepub const fn stable_attribute(&self) -> &AttributeId
pub const fn stable_attribute(&self) -> &AttributeId
Return the exact historical attribute used for stable partition order.