ProjectionConfig

Enum ProjectionConfig 

#[non_exhaustive]
pub enum ProjectionConfig {
#[non_exhaustive]
Python { naming_policy: PythonNamingPolicy, type_name_overrides: Vec<TypeNameOverride>, },
#[non_exhaustive]
TypeScript { naming_policy: TypeScriptNamingPolicy, type_name_overrides: Vec<TypeNameOverride>, },
#[non_exhaustive]
Rust { naming_policy: RustNamingPolicy, type_name_overrides: Vec<TypeNameOverride>, create_policy: RustCreatePolicy, },
#[non_exhaustive]
C { naming_policy: CNamingPolicy, type_name_overrides: Vec<TypeNameOverride>, symbol_prefix: CSymbolPrefix, }, }
Target-specific options that are consumed by a shipped emitter.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


#[non_exhaustive]
Python

Python projection options.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
naming_policy: PythonNamingPolicy

Versioned Python naming behavior used for every generated symbol.

type_name_overrides: Vec<TypeNameOverride>

Explicit model names, sorted by canonical type identity.



#[non_exhaustive]
TypeScript

TypeScript projection options.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
naming_policy: TypeScriptNamingPolicy

Versioned TypeScript naming behavior used for every generated symbol.

type_name_overrides: Vec<TypeNameOverride>

Explicit model names, sorted by canonical type identity.



#[non_exhaustive]
Rust

Native Rust projection options.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
naming_policy: RustNamingPolicy

Versioned Rust naming behavior used for every generated symbol.

type_name_overrides: Vec<TypeNameOverride>

Explicit model names, sorted by canonical type identity.

create_policy: RustCreatePolicy

Versioned checked construction surface generated for constructible models.



#[non_exhaustive]
C

C projection options.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
naming_policy: CNamingPolicy

Versioned C naming behavior used for every generated symbol.

type_name_overrides: Vec<TypeNameOverride>

Explicit model names, sorted by canonical type identity.

symbol_prefix: CSymbolPrefix

Application-specific prefix for C’s global link namespace.

Implementations

Source

impl ProjectionConfig

pub const fn python() -> Self

Construct the initial Python projection configuration.

pub const fn typescript() -> Self

Construct the initial TypeScript projection configuration.

pub const fn rust() -> Self

Construct the initial native Rust projection configuration.

pub fn c(symbol_prefix: CSymbolPrefix) -> Self

Construct the initial C projection configuration.

pub fn with_type_name_override( self, type_id: TypeId, name: impl Into<String>, ) -> Result<Self, Diagnostic>

Add an exact model type-name override without changing database names.

Duplicate identities are rejected. Projection validates schema membership and collisions with other model names and generated helper names.

pub fn validate_type_name_overrides(&self) -> Result<(), Diagnostic>

Validate overrides after configuration assembly or external mutation.

pub fn type_name_overrides(&self) -> &[TypeNameOverride]

Return explicit model names in canonical identity order.

pub const fn target(&self) -> BindingTarget

Return the binding target that consumes this configuration.

pub const fn python_naming_policy(&self) -> Option<PythonNamingPolicy>

Return the Python naming policy when this is a Python config.

pub const fn typescript_naming_policy(&self) -> Option<TypeScriptNamingPolicy>

Return the TypeScript naming policy when this is a TypeScript config.

pub const fn rust_naming_policy(&self) -> Option<RustNamingPolicy>

Return the Rust naming policy when this is a Rust config.

pub const fn rust_create_policy(&self) -> Option<RustCreatePolicy>

Return the checked Rust create policy when this is a Rust config.

pub const fn c_naming_policy(&self) -> Option<CNamingPolicy>

Return the C naming policy when this is a C config.

pub const fn c_symbol_prefix(&self) -> Option<&CSymbolPrefix>

Return the symbol prefix when this is a C config.