QueryReductionGroupV2

Enum QueryReductionGroupV2 

pub enum QueryReductionGroupV2 {
    Binding {
        binding: BindingId,
    },
    Field {
        field: QueryFieldV2,
    },
    Fields {
        fields: Vec<QueryFieldV2>,
    },
}
Optional grouping contract for one model-compatible reduction terminal.

Variants



Binding

Group by one attached thing identity.

Fields

binding: BindingId

Attached grouping binding.



Field

Group by each witnessed value of one owned field.

Fields

field: QueryFieldV2

Descriptor-qualified grouping field.



Fields

Group by the Cartesian product of multiple owned field values.

Fields

fields: Vec<QueryFieldV2>

Ordered descriptor-qualified grouping fields.

Implementations

Source

impl QueryReductionGroupV2

pub const fn binding(binding: BindingId) -> Self

Construct a thing-identity grouping contract.

pub const fn field(field: QueryFieldV2) -> Self

Construct a single-field grouping contract.

pub const fn fields(fields: Vec<QueryFieldV2>) -> Self

Construct a tuple-field grouping contract.