pub enum QueryReductionKindV2 {
Count,
Sum,
Min,
Max,
Mean,
Median,
Std,
}Expand description
The closed reducer vocabulary used by model-compatible V2 terminals.
Variants
Count
Count distinct reduced roots.
Sum
Sum a numeric scalar field.
Min
Select the smallest numeric scalar field value.
Max
Select the largest numeric scalar field value.
Mean
Compute the arithmetic mean.
Median
Compute the statistical median.
Std
Compute the sample standard deviation.
Implementations
Sourceimpl QueryReductionKindV2
impl QueryReductionKindV2
Sourcepub const fn requires_input(self) -> bool
pub const fn requires_input(self) -> bool
Return whether this reducer consumes a numeric scalar field.
Sourcepub const fn widens_to_double(self) -> bool
pub const fn widens_to_double(self) -> bool
Return whether this reducer always returns the double domain.