pub struct QueryStableOrderV2 { /* private fields */ }Expand description
A validator-proven stable total order.
Implementations
Sourceimpl QueryStableOrderV2
impl QueryStableOrderV2
Sourcepub const fn new(
terms: Vec<QueryOrderTermV2>,
identity_tiebreakers: Vec<BindingId>,
) -> Self
pub const fn new( terms: Vec<QueryOrderTermV2>, identity_tiebreakers: Vec<BindingId>, ) -> Self
Construct one stable order with its explicit identity tie breaker.
Sourcepub fn terms(&self) -> &[QueryOrderTermV2]
pub fn terms(&self) -> &[QueryOrderTermV2]
Return public field terms.
Sourcepub fn identity_tiebreakers(&self) -> &[BindingId]
pub fn identity_tiebreakers(&self) -> &[BindingId]
Return the canonical identity tuple that makes the order total.