pub enum TypeReference {
Value(ValueTypeTag),
Schema(Label),
}Expand description
A type reference used by a function signature.
Variants
Value(ValueTypeTag)
One of the closed built-in scalar value types.
Schema(Label)
A schema type or struct label resolved against the declared graph.
Implementations
Sourceimpl TypeReference
impl TypeReference
Sourcepub fn from_token(value: impl Into<String>) -> Result<Self, Diagnostic>
pub fn from_token(value: impl Into<String>) -> Result<Self, Diagnostic>
Parse the unambiguous TypeQL type-position spelling.
Sourcepub const fn schema_label(&self) -> Option<&Label>
pub const fn schema_label(&self) -> Option<&Label>
Return the referenced schema label, if this is not a built-in value type.