pub struct CanonicalValueRange { /* private fields */ }Expand description
An exact-domain, non-empty canonical value range.
Implementations
Sourceimpl CanonicalValueRange
impl CanonicalValueRange
Sourcepub fn new(
lower: Option<CanonicalValue>,
upper: Option<CanonicalValue>,
) -> Result<Self, Diagnostic>
pub fn new( lower: Option<CanonicalValue>, upper: Option<CanonicalValue>, ) -> Result<Self, Diagnostic>
Validate a range with at least one bound and one exact scalar domain.
Sourcepub fn new_detailed(
lower: Option<CanonicalValue>,
upper: Option<CanonicalValue>,
) -> Result<Self, CanonicalValueRangeViolation>
pub fn new_detailed( lower: Option<CanonicalValue>, upper: Option<CanonicalValue>, ) -> Result<Self, CanonicalValueRangeViolation>
Validate bounds while retaining the exact failure for source diagnostics.
Sourcepub const fn lower(&self) -> Option<&CanonicalValue>
pub const fn lower(&self) -> Option<&CanonicalValue>
Return the lower bound.
Sourcepub const fn upper(&self) -> Option<&CanonicalValue>
pub const fn upper(&self) -> Option<&CanonicalValue>
Return the upper bound.