Module value

Module value 

Domain-tagged canonical scalar, cardinality, and annotation values. Domain-tagged canonical scalar, cardinality, and annotation values.

Structs

CanonicalDouble
A finite IEEE-754 double represented by its exact bits.
CanonicalString
Validated UTF-8 text bounded by the canonical per-string byte ceiling.
Cardinality
A validated cardinality. None means an unbounded maximum.
DecimalValue
An owned validated canonical decimal spelling.

Enums

AnnotationValue
A generic canonical annotation value without freezing annotation fact DTOs.
CanonicalValue
A canonical scalar value with an explicit domain tag.
ValueTypeTag
The closed TypeDB scalar-domain vocabulary.