ProjectionConfig

Enum ProjectionConfig 

pub enum ProjectionConfig {
    Python {
        naming_policy: PythonNamingPolicy,
    },
    TypeScript {
        naming_policy: TypeScriptNamingPolicy,
    },
    Rust {
        naming_policy: RustNamingPolicy,
        create_policy: RustCreatePolicy,
    },
}
Target-specific options that are consumed by a shipped emitter.

Variants



Python

Python projection options.

Fields

naming_policy: PythonNamingPolicy

Versioned Python naming behavior used for every generated symbol.



TypeScript

TypeScript projection options.

Fields

naming_policy: TypeScriptNamingPolicy

Versioned TypeScript naming behavior used for every generated symbol.



Rust

Native Rust projection options.

Fields

naming_policy: RustNamingPolicy

Versioned Rust naming behavior used for every generated symbol.

create_policy: RustCreatePolicy

Versioned checked construction surface generated for constructible models.

Implementations

Source

impl ProjectionConfig

pub const fn python() -> Self

Construct the initial Python projection configuration.

pub const fn typescript() -> Self

Construct the initial TypeScript projection configuration.

pub const fn rust() -> Self

Construct the initial native Rust projection configuration.

pub const fn target(&self) -> BindingTarget

Return the binding target that consumes this configuration.

pub const fn typescript_naming_policy(&self) -> Option<TypeScriptNamingPolicy>

Return the TypeScript naming policy when this is a TypeScript config.

pub const fn rust_naming_policy(&self) -> Option<RustNamingPolicy>

Return the Rust naming policy when this is a Rust config.

pub const fn rust_create_policy(&self) -> Option<RustCreatePolicy>

Return the checked Rust create policy when this is a Rust config.