pub struct RuntimeProjection { /* private fields */ }Expand description
A validated target-specific runtime projection derived from resolved semantics.
Implementations
Sourceimpl RuntimeProjection
impl RuntimeProjection
Sourcepub fn try_new(
target: BindingTarget,
config: ProjectionConfig,
semantic_fingerprint: SemanticSchemaFingerprint,
handlers: &[ProjectionHandler],
resources: &[CodeResourceDigest],
models: BTreeMap<TypeId, ModelProjection>,
structs: BTreeMap<StructId, StructProjection>,
functions: BTreeMap<FunctionId, FunctionProjection>,
playing_facts: BTreeMap<PlaysFactId, PlayingProjection>,
emission: EmissionPlan,
) -> Result<Self, Diagnostic>
pub fn try_new( target: BindingTarget, config: ProjectionConfig, semantic_fingerprint: SemanticSchemaFingerprint, handlers: &[ProjectionHandler], resources: &[CodeResourceDigest], models: BTreeMap<TypeId, ModelProjection>, structs: BTreeMap<StructId, StructProjection>, functions: BTreeMap<FunctionId, FunctionProjection>, playing_facts: BTreeMap<PlaysFactId, PlayingProjection>, emission: EmissionPlan, ) -> Result<Self, Diagnostic>
Validate a complete projection graph and compute its content-bound fingerprint.
Sourcepub const fn target(&self) -> BindingTarget
pub const fn target(&self) -> BindingTarget
Return the binding target.
Sourcepub const fn config(&self) -> &ProjectionConfig
pub const fn config(&self) -> &ProjectionConfig
Return the exact projection configuration.
Sourcepub const fn semantic_fingerprint(&self) -> &SemanticSchemaFingerprint
pub const fn semantic_fingerprint(&self) -> &SemanticSchemaFingerprint
Return the source semantic schema fingerprint.
Sourcepub const fn projection_fingerprint(&self) -> &BindingProjectionFingerprint
pub const fn projection_fingerprint(&self) -> &BindingProjectionFingerprint
Return the content-bound target projection fingerprint.
Sourcepub fn generator_handlers(&self) -> &[ProjectionHandler]
pub fn generator_handlers(&self) -> &[ProjectionHandler]
Return the ordered handler evidence committed by the projection fingerprint.
Sourcepub fn code_resources(&self) -> &[CodeResourceDigest]
pub fn code_resources(&self) -> &[CodeResourceDigest]
Return the ordered code-resource evidence committed by the projection fingerprint.
Sourcepub const fn models(&self) -> &BTreeMap<TypeId, ModelProjection>
pub const fn models(&self) -> &BTreeMap<TypeId, ModelProjection>
Return projected models in canonical identity order.
Sourcepub const fn structs(&self) -> &BTreeMap<StructId, StructProjection>
pub const fn structs(&self) -> &BTreeMap<StructId, StructProjection>
Return projected structs in canonical identity order.
Sourcepub const fn functions(&self) -> &BTreeMap<FunctionId, FunctionProjection>
pub const fn functions(&self) -> &BTreeMap<FunctionId, FunctionProjection>
Return projected schema functions in canonical identity order.
Sourcepub const fn playing_facts(&self) -> &BTreeMap<PlaysFactId, PlayingProjection>
pub const fn playing_facts(&self) -> &BTreeMap<PlaysFactId, PlayingProjection>
Return effective per-player metadata keyed by exact playing identity.
Sourcepub const fn emission(&self) -> &EmissionPlan
pub const fn emission(&self) -> &EmissionPlan
Return the shells-first generation schedule.