pub enum QueryReductionGroupV2 {
Binding {
binding: BindingId,
},
Field {
field: QueryFieldV2,
},
Fields {
fields: Vec<QueryFieldV2>,
},
}Expand description
Optional grouping contract for one model-compatible reduction terminal.
Variants
Binding
Group by one attached thing identity.
Field
Group by each witnessed value of one owned field.
Fields

field: QueryFieldV2Descriptor-qualified grouping field.
Fields
Group by the Cartesian product of multiple owned field values.
Fields

fields: Vec<QueryFieldV2>Ordered descriptor-qualified grouping fields.
Implementations
Sourceimpl QueryReductionGroupV2
impl QueryReductionGroupV2
Sourcepub const fn field(field: QueryFieldV2) -> Self
pub const fn field(field: QueryFieldV2) -> Self
Construct a single-field grouping contract.
Sourcepub const fn fields(fields: Vec<QueryFieldV2>) -> Self
pub const fn fields(fields: Vec<QueryFieldV2>) -> Self
Construct a tuple-field grouping contract.